@@ -1,8 +1,8 @@
-;;; reftex-dcr.el - Viewing cross references and citations with RefTeX
+;;; reftex-dcr.el --- viewing cross references and citations with RefTeX
 ;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
 
-;; Author:     Carsten Dominik <dominik@strw.LeidenUniv.nl>
-;; Version: 4.14
+;; Author: Carsten Dominik <dominik@science.uva.nl>
+;; Version: 4.18
 ;;
 
 ;; This file is part of GNU Emacs.
@@ -22,6 +22,10 @@
 ;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 ;; Boston, MA 02111-1307, USA.
 
+;;; Commentary:
+
+;;; Code:
+
 (eval-when-compile (require 'cl))
 (provide 'reftex-dcr)
 (provide 'reftex-vcr)
@@ -30,12 +34,12 @@
 
 (defun reftex-view-crossref (&optional arg auto-how)
   "View cross reference of macro at point.  Point must be on the KEY
-argument.  When at at `\ref' macro, show corresponding `\label'
+argument.  When at at `\\ref' macro, show corresponding `\\label'
 definition, also in external documents (`xr').  When on a label, show
 a locations where KEY is referenced.  Subsequent calls find additional
-locations.  When on a `\cite', show the associated `\bibitem' macro or
-the BibTeX database entry.  When on a `\bibitem', show a `\cite' macro
-which uses this KEY. When on an `\index', show other locations marked
+locations.  When on a `\\cite', show the associated `\\bibitem' macro or
+the BibTeX database entry.  When on a `\\bibitem', show a `\\cite' macro
+which uses this KEY. When on an `\\index', show other locations marked
 by the same index entry.
 To define additional cross referencing items, use the option
 `reftex-view-crossref-extra'.  See also `reftex-view-crossref-from-bibtex'.
@@ -47,7 +51,7 @@ to the functions `reftex-view-cr-cite' and `reftex-view-cr-ref'."
   (interactive "P")
   ;; See where we are.
   (let* ((macro (car (reftex-what-macro-safe 1)))
-         (key (reftex-this-word "^{}%\n\r,"))
+         (key (reftex-this-word "^{}%\n\r, \t"))
 	 dw)
 
     (if (or (null macro) (reftex-in-comment))
