@@ -1,9 +1,8 @@
-;;; reftex-index.el - Index support with RefTeX
+;;; reftex-index.el --- index support with RefTeX
 ;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
 
-;; Author:     Carsten Dominik <dominik@strw.LeidenUniv.nl>
-;; Version: 4.16
-;;
+;; Author: Carsten Dominik <dominik@science.uva.nl>
+;; Version: 4.18
 
 ;; This file is part of GNU Emacs.
 
@@ -22,14 +21,15 @@
 ;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 ;; Boston, MA 02111-1307, USA.
 
+;;; Commentary:
+
+;;; Code:
+
 (eval-when-compile (require 'cl))
 (provide 'reftex-index)
 (require 'reftex)
 ;;;
 
-(defvar mark-active)
-(defvar zmacs-regions)
-(defvar transient-mark-mode)
 (defun reftex-index-selection-or-word (&optional arg phrase)
   "Put selection or the word near point into the default index macro.
 This uses the information in `reftex-index-default-macro' to make an index
@@ -320,7 +320,7 @@ s          Switch to a different index (for documents with multiple indices).
 e / C-k    Edit/Kill the entry.
 * | @      Edit specific part of entry: [*]key [|]attribute [@]visual
            With prefix: kill that part.
-( )        Toggle entry's beginning/end of page range property.
+\( )        Toggle entry's beginning/end of page range property.
 _ ^        Add/Remove parent key (to make this item a subitem).
 } / {      Restrict Index to a single document section / Widen.
 < / >      When restricted, move restriction to previous/next section.")
@@ -1818,6 +1818,9 @@ both ends."
     (unwind-protect
 	(while (re-search-forward re nil t)
 	  (catch 'next-match
+	    (if (and (fboundp reftex-index-verify-function)
+		     (not (funcall reftex-index-verify-function)))
+		(throw 'next-match nil))
 	    (setq match (match-string 0))
 	    (setq mathp
 		  (save-match-data
