@@ -1,8 +1,8 @@
-;;; reftex-parse.el - Parser Functions for RefTeX
+;;; reftex-parse.el --- parser functions for RefTeX
 ;; Copyright (c) 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
 
-;; Author:     Carsten Dominik <dominik@strw.LeidenUniv.nl>
-;; Version: 4.11
+;; Author: Carsten Dominik <dominik@science.uva.nl>
+;; Version: 4.18
 ;;
 
 ;; This file is part of GNU Emacs.
@@ -22,6 +22,10 @@
 ;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 ;; Boston, MA 02111-1307, USA.
 
+;;; Commentary:
+
+;;; Code:
+
 (eval-when-compile (require 'cl))
 (provide 'reftex-parse)
 (require 'reftex)
@@ -330,9 +334,13 @@ of master file."
     (save-excursion
       (goto-char (point-min))
       (if (re-search-forward
-	   "\\(\\`\\|[\n\r]\\)[ \t]*\\\\bibliography{[ \t]*\\([^}]+\\)" nil t)
+	   (concat
+;	    "\\(\\`\\|[\n\r]\\)[^%]*\\\\\\("
+	    "\\(^\\)[^%]*\\\\\\("
+	    (mapconcat 'identity reftex-bibliography-commands "\\|")
+	    "\\){[ \t]*\\([^}]+\\)") nil t)
 	  (setq files 
-		(split-string (reftex-match-string 2)
+		(split-string (reftex-match-string 3)
 			      "[ \t\n\r]*,[ \t\n\r]*")))))
   (when files
     (setq files 
